==> aipark-api-27.2-sources.jar: de/aipark/api/requestsResponse/getParkingAreasForPositionWithOccupancyForDeparture/GetParkingAreasForPositionWithOccupancyForDepartureRequest.java <==
package de.aipark.api.requestsResponse.getParkingAreasForPositionWithOccupancyForDeparture;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.vividsolutions.jts.geom.Point;
import de.aipark.api.parkingarea.ParkingAreaDataFilter;
import de.aipark.api.requestsResponse.FiltersDeserializer;
import de.aipark.api.requestsResponse.Request;
import io.swagger.annotations.ApiModelProperty;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by torgen on 27.09.17.
 */
public class GetParkingAreasForPositionWithOccupancyForDepartureRequest extends Request {
    @ApiModelProperty(value = "departurePosition of parking areas", required = true)
    private Point destinationPosition;

    @ApiModelProperty(value = "number of parking areas", dataType = "java.lang.Integer", required = true, example = "10")
    private Integer numberOfParkingAreas;

    @ApiModelProperty(value = "list of filters", dataType = "List<ParkingAreaDataFilter>", required = true)
    @JsonDeserialize(using = FiltersDeserializer.class)
    private List<ParkingAreaDataFilter> filters = new ArrayList<ParkingAreaDataFilter>();

    @ApiModelProperty(value = "departure position", required = true)
    private Point departurePosition;

    @ApiModelProperty(value = "departure time", dataType = "java.lang.Long", required = true, example = "1476561575000")
    private Timestamp departureTimestamp;

    public GetParkingAreasForPositionWithOccupancyForDepartureRequest() {
    }

    public GetParkingAreasForPositionWithOccupancyForDepartureRequest(Point destinationPosition, Integer numberOfParkingAreas, List<ParkingAreaDataFilter> filters, Point departurePosition, Timestamp departureTimestamp) {
        this.destinationPosition = destinationPosition;
        this.numberOfParkingAreas = numberOfParkingAreas;
        this.filters = filters;
        this.departurePosition = departurePosition;
        this.departureTimestamp = departureTimestamp;
    }

    public Point getDestinationPosition() {
        return destinationPosition;
    }

    public void setDestinationPosition(Point destinationPosition) {
        this.destinationPosition = destinationPosition;
    }

    public Integer getNumberOfParkingAreas() {
        return numberOfParkingAreas;
    }

    public void setNumberOfParkingAreas(Integer numberOfParkingAreas) {
        this.numberOfParkingAreas = numberOfParkingAreas;
    }

    public List<ParkingAreaDataFilter> getFilters() {
        return filters;
    }

    public void setFilters(List<ParkingAreaDataFilter> filters) {
        this.filters = filters;
    }

    public Point getDeparturePosition() {
        return departurePosition;
    }

    public void setDeparturePosition(Point departurePosition) {
        this.departurePosition = departurePosition;
    }

    public Timestamp getDepartureTimestamp() {
        return departureTimestamp;
    }

    public void setDepartureTimestamp(Timestamp departureTimestamp) {
        this.departureTimestamp = departureTimestamp;
    }
}

==> aipark-api-28.32-sources.jar: de/aipark/api/requestsResponse/getParkingAreasForPositionWithOccupancyForDeparture/GetParkingAreasForPositionWithOccupancyForDepartureRequest.java <==
package de.aipark.api.requestsResponse.getParkingAreasForPositionWithOccupancyForDeparture;

import com.vividsolutions.jts.geom.Point;
import de.aipark.api.parkingarea.ParkingAreaDataFilter;
import io.swagger.annotations.ApiModelProperty;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by torgen on 27.09.17.
 */
public class GetParkingAreasForPositionWithOccupancyForDepartureRequest {
    @ApiModelProperty(value = "departurePosition of parking areas", required = true)
    private Point destinationPosition;

    @ApiModelProperty(value = "number of parking areas", dataType = "java.lang.Integer", required = true, example = "10")
    private Integer numberOfParkingAreas;

    @ApiModelProperty(value = "list of filters, filter CAR_PARK combines filters for types: \"CAR_PARK, AIRPORT,PARKING_DECK_AUTOMATED, UNDERGROUND_PARKING, UNDERGROUND_PARKING_AUTOMATED \"",
            dataType = "[Ljava.lang.String;", example = "[\"FREE\"]", required = true,
            allowableValues = ParkingAreaDataFilter.ALLOWED_VALUES_LIST)
    private List<ParkingAreaDataFilter> filters = new ArrayList<ParkingAreaDataFilter>();

    @ApiModelProperty(value = "departure position", required = true)
    private Point departurePosition;

    @ApiModelProperty(value = "departure time (UNIX time (since 1970) in milliseconds)", dataType = "java.lang.Long", required = true, example = "1476561575000")
    private Timestamp departureTimestamp;

    public GetParkingAreasForPositionWithOccupancyForDepartureRequest() {
    }

    public GetParkingAreasForPositionWithOccupancyForDepartureRequest(Point destinationPosition, Integer numberOfParkingAreas, List<ParkingAreaDataFilter> filters, Point departurePosition, Timestamp departureTimestamp) {
        this.destinationPosition = destinationPosition;
        this.numberOfParkingAreas = numberOfParkingAreas;
        this.filters = filters;
        this.departurePosition = departurePosition;
        this.departureTimestamp = departureTimestamp;
    }

    public Point getDestinationPosition() {
        return destinationPosition;
    }

    public void setDestinationPosition(Point destinationPosition) {
        this.destinationPosition = destinationPosition;
    }

    public Integer getNumberOfParkingAreas() {
        return numberOfParkingAreas;
    }

    public void setNumberOfParkingAreas(Integer numberOfParkingAreas) {
        this.numberOfParkingAreas = numberOfParkingAreas;
    }

    public List<ParkingAreaDataFilter> getFilters() {
        return filters;
    }

    public void setFilters(List<ParkingAreaDataFilter> filters) {
        this.filters = filters;
    }

    public Point getDeparturePosition() {
        return departurePosition;
    }

    public void setDeparturePosition(Point departurePosition) {
        this.departurePosition = departurePosition;
    }

    public Timestamp getDepartureTimestamp() {
        return departureTimestamp;
    }

    public void setDepartureTimestamp(Timestamp departureTimestamp) {
        this.departureTimestamp = departureTimestamp;
    }

    @Override
    public String toString() {
        return "GetParkingAreasForPositionWithOccupancyForDepartureRequest{" +
                "destinationPosition=" + destinationPosition +
                ", numberOfParkingAreas=" + numberOfParkingAreas +
                ", filters=" + filters +
                ", departurePosition=" + departurePosition +
                ", departureTimestamp=" + departureTimestamp +
                '}';
    }
}
